"""
.. _This file was initially part of SPPAS: https://sppas.org/
.. _This file is now part of WhakerPy: https://whakerpy.sourceforge.io
..
    -------------------------------------------------------------------------

    Copyright (C) 2023-2024 Brigitte Bigi
    Laboratoire Parole et Langage, Aix-en-Provence, France

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    This banner notice must not be removed.

    -------------------------------------------------------------------------
"""

# This is a list of tags which can only be empty (to be completed)
HTML_EMPTY_TAGS = {
    "br": "inserts a single line break",
    "img": "image",
    "hr": "horizontal rule",
    "input": "input field",
    "meta": "",
    "link": ""
}

# This is the whole list of HTML tags. It should be split into 2:
# the ones that can be empty and the ones that can't (in HTMLNode).
# Moreover, each tag should be linked to its possible attributes.
HTML_TAGS = {
    "a": "hyperlink",
    "abbr": "abbreviation",
    "address": "address element",
    "area": "area inside an image map",
    "article": "article",
    "aside": "content aside from the page content",
    "audio": "sound content",
    "b": "bold text",
    "base": "base URL for all the links in a page",
    "bdi": "for bi-directional text formatting",
    "bdo": "the direction of text display",
    "blockquote": "long quotation",
    "body": "the body element",
    "br": "inserts a single line break",
    "button": "button form control",
    "canvas": "define graphics",
    "caption": "table caption",
    "cite": "citation",
    "code": "computer code text",
    "col": "attributes for table columns",
    "colgroup": "groups of table columns",
    "data": "allows for machine-readable data to be provided",
    "datalist": "autocomplete dropdown list",
    "dd": "definition description",
    "del": "deleted text",
    "details": "details of an element",
    "dfn": "defines a definition term",
    "dialog": "that part of an application is interactive",
    "div": "section in a document",
    "dl": "definition list",
    "dt": "definition term",
    "em": "emphasized text",
    "embed": "external application or interactive content",
    "fieldset": "fieldset",
    "figcaption": "caption for the figure element",
    "figure": "group of media content, and their caption",
    "footer": "footer for a section or page",
    "form": "form",
    "h1": "heading level 1",
    "h2": "heading level 2",
    "h3": "heading level 3",
    "h4": "heading level 4",
    "h5": "heading level 5",
    "h6": "heading level 6",
    "head": "information about the document",
    "header": "group of introductory or navigational aids, including hgroup elements",
    "hgroup": "header for a section or page",
    "hr": "horizontal rule",
    "html": "html document",
    "i": "italic text",
    "iframe": "inline sub window (frame)",
    "img": "image",
    "input": "input field",
    "ins": "inserted text",
    "kbd": "keyboard text",
    "label": "label for a form control",
    "legend": "title in a fieldset",
    "li": "list item",
    "link": "resource reference",
    "main": "the main content area of an HTML document",
    "map": "image map",
    "mark": "marked text",
    "menu": "toolbar consisting of its contents, in the form of an unordered list of items",
    "meta": "meta information",
    "meter": "measurement within a predefined range",
    "nav": "navigation links",
    "noscript": "noscript section",
    "object": "embedded object",
    "ol": "ordered list",
    "optgroup": "option group",
    "option": "option in a drop-down list",
    "output": "some types of output",
    "p": "paragraph",
    "param": "parameter for an object",
    "picture": "container that provides multiple sources to its contained img element",
    "pre": "preformatted text",
    "progress": "progress of a task of any kind",
    "q": "short quotation",
    "rb": "marks the base text component of a ruby annotation",
    "rp": "used for the benefit of browsers that don't support ruby annotations",
    "rt": "ruby text component of a ruby annotation",
    "rtc": "marks the ruby text container for ruby text components in a ruby annotation",
    "ruby": "ruby annotation (used in East Asian typography)",
    "s": "Indicates text that's no longer accurate or relevant",
    "samp": "sample computer code",
    "script": "script",
    "section": "section",
    "select": "selectable list",
    "slot": "defines a slot, typically in a shadow tree",
    "small": "small text",
    "source": "media resources",
    "span": "section in a document",
    "strong": "strong text",
    "style": "style definition",
    "sub": "subscripted text",
    "summary": "summary / caption for the <details> element",
    "sup": "superscripted text",
    "table": "table",
    "tbody": "table body",
    "td": "table cell",
    "template": "allows to declare an HTML fragment that can be cloned and inserted in the document by script",
    "textarea": "text area",
    "tfoot": "table footer",
    "th": "table header",
    "thead": "table header",
    "time": "date/time",
    "title": "the document title",
    "tr": "table row",
    "track": "text track for media such as video and audio",
    "u": "text with a non-textual annotation",
    "ul": "unordered list",
    "var": "variable",
    "video": "video",
    "wbr": "line break opportunity for very long words and strings of text with no spaces"
}

HTML_GLOBAL_ATTR = (
    "accesskey",
    "class",
    "contenteditable",
    "data-*",
    "dir",
    "draggable",
    "hidden",
    "id",
    "lang",
    "spellcheck",
    "style",
    "tabindex",
    "title",
    "translate",
)

HTML_VISIBLE_ATTR = (
    "onblur",
    "onchange",
    "onclick",
    "oncontextmenu",
    "oncopy",
    "oncut",
    "ondblclick",
    "ondrag",
    "ondragend",
    "ondragenter",
    "ondragleave",
    "ondragover",
    "ondragstart",
    "ondrop",
    "onfocus",
    "oninput",
    "oninvalid",
    "onkeydown",
    "onkeypress",
    "onkeyup",
    "onmousedown",
    "onmousemove",
    "onmouseout",
    "onmouseover",
    "onmouseup",
    "onmousewheel",
    "onpaste",
    "onscroll",
    "onselect",
    "onwheel",
)

HTML_TAG_ATTR = {
    "accept": ("input",),
    "accept-charset": ("form",),
    "action": ("form",),
    "alt": ("area", "img", "input"),
    "async": ("script",),
    "autocomplete": ("form", "input"),
    "autofocus": ("button", "input", "select", "textarea"),
    "autoplay": ("audio", "video"),
    "charset": ("meta", "script"),
    "checked": ("input",),
    "cite": ("blockquote", "del", "ins", "q"),
    "cols": ("textarea",),
    "colspan": ("td", "th"),
    "content": ("meta",),
    "controls": ("audio", "video"),
    "coords": ("area",),
    "data": ("object",),
    "datetime": ("del", "ins", "time"),
    "default": ("track",),
    "defer": ("script",),
    "dirname": ("input", "textarea",),
    "disabled": ("button", "fieldset", "input", "optgroup", "option", "select", "textarea"),
    "download": ("a", "area"),
    "enctype": ("form",),
    "for": ("label", "output"),
    "form": ("button", "fieldset", "input", "label", "meter", "object", "output", "select", "textarea"),
    "formaction": ("button", "input"),
    "headers": ("td", "th"),
    "height": ("canvas", "embed", "iframe", "img", "input", "object", "video"),
    "high": ("meter",),
    "href": ("a", "area", "base", "link"),
    "hreflang": ("a", "area", "link"),
    "http-equiv": ("meta",),
    "ismap": ("img",),
    "kind": ("track",),
    "label": ("track", "option", "optgroup"),
    "list": ("input",),
    "loop": ("audio", "video"),
    "low": ("meter",),
    "max": ("input", "meter", "progress"),
    "maxlength": ("input", "textarea"),
    "media": ("a", "area", "link", "source", "style"),
    "method": ("form",),
    "min": ("input", "meter"),
    "multiple": ("input", "select"),
    "muted": ("video", "audio"),
    "name": ("button", "fieldset", "form", "iframe", "input", "map", "meta",
             "object", "output", "param", "select", "textarea"),
    "novalidate": ("form",),
    "onabort": ("audio", "embed", "img", "object", "video"),
    "onafterprint": ("body",),
    "onbeforeprint": ("body",),
    "onbeforeunload": ("body",),
    "oncanplay": ("audio", "embed", "object", "video"),
    "oncanplaythrough": ("audio", "video"),
    "oncuechange": ("track",),
    "ondurationchange": ("audio", "video"),
    "onemptied": ("audio", "video"),
    "onended": ("audio", "video"),
    "onerror": ("audio", "body", "embed", "img", "object", "script", "style", "video"),
    "onhashchange": ("body",),
    "onload": ("body", "iframe", "img", "input", "link", "script", "style"),
    "onloadeddata": ("audio", "video"),
    "onloadedmetadata": ("audio", "video"),
    "onloadstart": ("audio", "video"),
    "onoffline": ("body",),
    "ononline": ("body",),
    "onpagehide": ("body",),
    "onpageshow": ("body",),
    "onpause": ("audio", "video"),
    "onplay": ("audio", "video"),
    "onplaying": ("audio", "video"),
    "onpopstate": "(body )",
    "onprogress": ("audio", "video"),
    "onratechange": ("audio", "video"),
    "onreset": ("form",),
    "onresize": ("body",),
    "onsearch": ("input",),
    "onseeked": ("audio", "video"),
    "onseeking": ("audio", "video"),
    "onstalled": ("audio", "video"),
    "onstorage": ("body",),
    "onsubmit": ("form",),
    "onsuspend": ("audio", "video"),
    "ontimeupdate": ("audio", "video"),
    "ontoggle": ("details",),
    "onunload": ("body",),
    "onvolumechange": ("audio", "video"),
    "onwaiting": ("audio", "video"),
    "open": ("details",),
    "optimum": "(meter )",
    "pattern": ("input",),
    "placeholder": ("input", "textarea"),
    "poster": ("video",),
    "preload": ("audio", "video"),
    "readonly": ("input", "textarea"),
    "rel": ("a", "area", "form", "link"),
    "required": ("input", "select", "textarea"),
    "reversed": ("ol",),
    "rows": ("textarea",),
    "rowspan": ("td", "th"),
    "sandbox": ("iframe",),
    "scope": ("th",),
    "selected": ("option",),
    "shape": ("area",),
    "size": ("input", "select"),
    "sizes": ("img", "link", "source"),
    "span": ("col", "colgroup"),
    "src": ("audio", "embed", "iframe", "img", "input", "script", "source", "track", "video"),
    "srcdoc": ("iframe",),
    "srclang": ("track",),
    "srcset": ("img", "source"),
    "start": ("ol",),
    "step": ("input",),
    "target": ("a", "area", "base", "form"),
    "type": ("a", "button", "embed", "input", "link", "menu", "object", "script", "source", "style"),
    "usemap": ("img", "object"),
    "value": ("button", "input", "li", "option", "meter", "progress", "param"),
    "width": ("canvas", "embed", "iframe", "img", "input", "object", "video"),
    "wrap": ("textarea",)
}

ARIA_TAG_ATTR = {
    "role": ("none", "generic", "contentinfo", "banner"),
    "aria-labelledby": None,
    "aria-label": None,
    "aria-pressed": ("true", "false")
}

# List of accepted child tags in an HTML header.
HEAD_TAGS = ("title", "meta", "link", "style", "script")

